@@ -4,6 +4,9 @@ instail.
 An example python library.
 """
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __author__ = 'nkorzh'
-__credits__ = 'My home workplace'
\ No newline at end of file
+__credits__ = 'My home workplace'
+
+from instail.demo import demoprint
+from instail.demo import custom_sort
